@@ -18,11 +18,11 @@ class WidgetConfigurationToolsBase : public QWidget
 {
     Q_OBJECT
 
-    Q_PROPERTY( QStringList tools READ tools WRITE setTools NOTIFY changed USER true )
+    Q_PROPERTY(QStringList tools READ tools WRITE setTools NOTIFY changed USER true)
 
     public:
         explicit WidgetConfigurationToolsBase( QWidget * parent = nullptr );
-        ~WidgetConfigurationToolsBase();
+        ~WidgetConfigurationToolsBase() override;
 
         virtual QStringList tools() const = 0;
         virtual void setTools(const QStringList& items) = 0;
