@@ -202,7 +202,7 @@ class OKULARCORE_EXPORT Document : public QObject
         /**
          * Destroys the document.
          */
-        ~Document();
+        ~Document() override;
 
         /**
          * Describes the result of an open document operation.
@@ -491,9 +491,9 @@ class OKULARCORE_EXPORT Document : public QObject
         void requestPixmaps( const QLinkedList<PixmapRequest*> &requests, PixmapRequestFlags reqOptions );
 
         /**
-         * Sends a request for text page generation for the given page @p number.
+         * Sends a request for text page generation for the given page @p pageNumber.
          */
-        void requestTextPage( uint number );
+        void requestTextPage( uint pageNumber );
 
         /**
          * Adds a new @p annotation to the given @p page.
@@ -669,18 +669,18 @@ class OKULARCORE_EXPORT Document : public QObject
         void processAction( const Action *action );
 
         /**
-         * Processes the given format @p action on @p field.
+         * Processes the given format @p action on @p fft.
          *
          * @since 1.9
          */
-        void processFormatAction( const Action *action, Okular::FormFieldText *field );
+        void processFormatAction( const Action *action, Okular::FormFieldText *fft );
 
         /**
-         * Processes the given keystroke @p action on @p field.
+         * Processes the given keystroke @p action on @p fft.
          *
          * @since 1.9
          */
-        void processKeystrokeAction( const Action *action, Okular::FormFieldText *field, bool &returnCode );
+        void processKeystrokeAction( const Action *action, Okular::FormFieldText *fft, bool &returnCode );
 
         /**
          * Processes the given focus action on the field.
@@ -690,11 +690,11 @@ class OKULARCORE_EXPORT Document : public QObject
         void processFocusAction( const Action *action, Okular::FormField *field );
         
         /**
-         * Processes the given keystroke @p action on @p field.
+         * Processes the given keystroke @p action on @p fft.
          *
          * @since 1.9
          */
-        void processValidateAction( const Action *action, Okular::FormFieldText *field, bool &returnCode );
+        void processValidateAction( const Action *action, Okular::FormFieldText *fft, bool &returnCode );
         
         /**
          * Returns a list of the bookmarked.pages
@@ -976,6 +976,13 @@ class OKULARCORE_EXPORT Document : public QObject
         */
         QAbstractItemModel * layersModel() const;
 
+        /**
+         *  Returns the reason why the file opening failed, if any.
+         *
+         * @since 1.10
+         */
+        QString openError() const;
+
     public Q_SLOTS:
         /**
          * This slot is called whenever the user changes the @p rotation of
@@ -987,7 +994,7 @@ class OKULARCORE_EXPORT Document : public QObject
          * This slot is called whenever the user changes the page @p size
          * of the document.
          */
-        void setPageSize( const PageSize &size );
+        void setPageSize( const Okular::PageSize &size );
 
         /**
          * Cancels the current search
@@ -1066,6 +1073,13 @@ class OKULARCORE_EXPORT Document : public QObject
          */
         QByteArray requestSignedRevisionData( const Okular::SignatureInfo &info );
 
+        /**
+         * Refresh the pixmaps for the given @p pageNumber.
+         *
+         * @since 1.10
+         */
+        void refreshPixmaps( int pageNumber );
+
     Q_SIGNALS:
         /**
          * This signal is emitted whenever the document is about to close.
@@ -1267,21 +1281,6 @@ class OKULARCORE_EXPORT Document : public QObject
         DocumentPrivate *const d;
 
         Q_DISABLE_COPY( Document )
-
-        Q_PRIVATE_SLOT( d, void saveDocumentInfo() const )
-        Q_PRIVATE_SLOT( d, void slotTimedMemoryCheck() )
-        Q_PRIVATE_SLOT( d, void sendGeneratorPixmapRequest() )
-        Q_PRIVATE_SLOT( d, void rotationFinished( int page, Okular::Page *okularPage ) )
-        Q_PRIVATE_SLOT( d, void slotFontReadingProgress( int page ) )
-        Q_PRIVATE_SLOT( d, void fontReadingGotFont( const Okular::FontInfo& font ) )
-        Q_PRIVATE_SLOT( d, void slotGeneratorConfigChanged( const QString& ) )
-        Q_PRIVATE_SLOT( d, void refreshPixmaps( int ) )
-        Q_PRIVATE_SLOT( d, void _o_configChanged() )
-
-        // search thread simulators
-        Q_PRIVATE_SLOT( d, void doContinueDirectionMatchSearch(void *doContinueDirectionMatchSearchStruct) )
-        Q_PRIVATE_SLOT( d, void doContinueAllDocumentSearch(void *pagesToNotifySet, void *pageMatchesMap, int currentPage, int searchID) )
-        Q_PRIVATE_SLOT( d, void doContinueGooglesDocumentSearch(void *pagesToNotifySet, void *pageMatchesMap, int currentPage, int searchID, const QStringList & words) )
 };
 
 
@@ -1301,9 +1300,9 @@ class OKULARCORE_EXPORT DocumentViewport
         DocumentViewport( int number = -1 );
 
         /**
-         * Creates a new viewport from the given xml @p description.
+         * Creates a new viewport from the given @p xmlDesc.
          */
-        DocumentViewport( const QString &description );
+        DocumentViewport( const QString &xmlDesc );
 
         /**
          * Returns the viewport as xml description.
@@ -1411,6 +1410,9 @@ class OKULARCORE_EXPORT EmbeddedFile
          */
         virtual ~EmbeddedFile();
 
+        EmbeddedFile(const EmbeddedFile &) = delete;
+        EmbeddedFile &operator=(const EmbeddedFile &) = delete;
+
         /**
          * Returns the name of the file
          */
