@@ -49,7 +49,7 @@ Okular::NormalizedRect buildBoundingRectangleForButtons( const QList<Okular::For
     double right = 0.0;
     double bottom = 0.0;
 
-    foreach( FormFieldButton* formButton, formButtons )
+    for( const FormFieldButton *formButton : formButtons )
     {
         left = qMin<double>( left, formButton->rect().left );
         top = qMin<double>( top, formButton->rect().top );
@@ -363,21 +363,21 @@ EditTextCommand::EditTextCommand( const QString & newContents,
     }
     else if ( newContentsRightOfCursor() == oldContentsRightOfCursor() &&
               newContentsLeftOfCursor() == oldContentsLeftOfCursor().left(oldContentsLeftOfCursor().length() - 1) &&
-              oldContentsLeftOfCursor().right(1) != QLatin1String("\n") )
+              oldContentsLeftOfCursor().rightRef(1) != "\n" )
     {
         qCDebug(OkularCoreDebug) << "CharBackspace";
         m_editType = CharBackspace;
     }
     else if ( newContentsLeftOfCursor() == oldContentsLeftOfCursor() &&
               newContentsRightOfCursor() == oldContentsRightOfCursor().right(oldContentsRightOfCursor().length() - 1) &&
-              oldContentsRightOfCursor().left(1) != QLatin1String("\n") )
+              oldContentsRightOfCursor().leftRef(1) != "\n" )
     {
         qCDebug(OkularCoreDebug) << "CharDelete";
         m_editType = CharDelete;
     }
     else if ( newContentsRightOfCursor() == oldContentsRightOfCursor() &&
               newContentsLeftOfCursor().left( newContentsLeftOfCursor().length() - 1) == oldContentsLeftOfCursor() &&
-              newContentsLeftOfCursor().right(1) != QLatin1String("\n") )
+              newContentsLeftOfCursor().rightRef(1) != "\n" )
     {
         qCDebug(OkularCoreDebug) << "CharInsert";
         m_editType = CharInsert;
@@ -603,12 +603,12 @@ EditFormComboCommand::EditFormComboCommand( Okular::DocumentPrivate* docPriv,
     // Determine new and previous choice indices (if any)
     for ( int i = 0; i < m_form->choices().size(); i++ )
     {
-        if ( m_form->choices()[i] == m_prevContents )
+        if ( m_form->choices().at(i) == m_prevContents )
         {
             m_prevIndex = i;
         }
 
-        if ( m_form->choices()[i] == m_newContents )
+        if ( m_form->choices().at(i) == m_newContents )
         {
             m_newIndex = i;
         }
@@ -688,7 +688,7 @@ EditFormButtonsCommand::EditFormButtonsCommand( Okular::DocumentPrivate* docPriv
   m_prevButtonStates( QList< bool >() )
 {
     setText( i18nc( "Edit the state of a group of form buttons", "edit form button states" ) );
-    foreach( FormFieldButton* formButton, m_formButtons )
+    for ( const FormFieldButton *formButton : qAsConst(m_formButtons) )
     {
         m_prevButtonStates.append( formButton->state() );
     }
@@ -730,7 +730,7 @@ bool EditFormButtonsCommand::refreshInternalPageReferences( const QVector< Okula
 {
     const QList< FormFieldButton* > oldFormButtons = m_formButtons;
     m_formButtons.clear();
-    foreach( FormFieldButton* oldFormButton, oldFormButtons )
+    for ( FormFieldButton *oldFormButton : oldFormButtons )
     {
         FormFieldButton *button = dynamic_cast<FormFieldButton *>(Okular::PagePrivate::findEquivalentForm( newPagesVector[m_pageNumber], oldFormButton ));
         if ( !button )
@@ -743,7 +743,7 @@ bool EditFormButtonsCommand::refreshInternalPageReferences( const QVector< Okula
 
 void EditFormButtonsCommand::clearFormButtonStates()
 {
-    foreach( FormFieldButton* formButton, m_formButtons )
+    for ( FormFieldButton *formButton : qAsConst(m_formButtons) )
     {
         formButton->setState( false );
     }
