@@ -13,8 +13,11 @@
 #include "okularcore_export.h"
 #include "area.h"
 #include "annotations.h"
+#include "signatureutils.h"
 
-#include <QtCore/QStringList>
+#include <QStringList>
+
+#include <memory>
 
 namespace Okular {
 
@@ -25,6 +28,7 @@ class FormFieldPrivate;
 class FormFieldButtonPrivate;
 class FormFieldTextPrivate;
 class FormFieldChoicePrivate;
+class FormFieldSignaturePrivate;
 
 /**
  * @short The base interface of a form field.
@@ -61,7 +65,7 @@ class OKULARCORE_EXPORT FormField
         FieldType type() const;
 
         /**
-         * The bouding rect of the field, in normalized coordinates.
+         * The bounding rect of the field, in normalized coordinates.
          */
         virtual NormalizedRect rect() const = 0;
 
@@ -82,6 +86,14 @@ class OKULARCORE_EXPORT FormField
          */
         virtual QString uiName() const = 0;
 
+        /**
+         * The fully qualified name of the field, is used in the JavaScript
+         * scripts.
+         *
+         * @since 1.9
+         */
+        virtual QString fullyQualifiedName() const = 0;
+
         /**
          * Whether the field is read-only.
          */
@@ -106,6 +118,20 @@ class OKULARCORE_EXPORT FormField
          */
         virtual void setVisible( bool value );
 
+        /**
+          Whether this field is printable.
+          
+          @since 1.9
+        */
+        virtual bool isPrintable() const;
+
+        /**
+          Set this field printable
+          
+          @since 1.9
+        */
+        virtual void setPrintable( bool value );
+
         Action* activationAction() const;
 
         /**
@@ -173,7 +199,7 @@ class OKULARCORE_EXPORT FormFieldButton : public FormField
             Radio          ///< A radio button.
         };
 
-        virtual ~FormFieldButton();
+        ~FormFieldButton() override;
 
         /**
           The particular type of the button field.
@@ -203,6 +229,13 @@ class OKULARCORE_EXPORT FormFieldButton : public FormField
          */
         virtual QList< int > siblings() const = 0;
 
+        /**
+         * Sets the icon of the Button to the Icon of the field parameter.
+         *
+         * @since 1.9
+        */
+        virtual void setIcon( Okular::FormField *field );
+
     protected:
         FormFieldButton();
 
@@ -231,7 +264,7 @@ class OKULARCORE_EXPORT FormFieldText : public FormField
             FileSelect     ///< An input field to select the path of a file on disk.
         };
 
-        virtual ~FormFieldText();
+        ~FormFieldText() override;
 
         /**
          * The particular type of the text field.
@@ -284,6 +317,13 @@ class OKULARCORE_EXPORT FormFieldText : public FormField
          */
         virtual bool canBeSpellChecked() const;
 
+        /**
+         * Set the text which should be rendered by the PDF.
+         *
+         * @since 1.9
+         */
+        virtual void setAppearanceText( const QString &text ) = 0;
+
     protected:
         FormFieldText();
 
@@ -312,7 +352,7 @@ class OKULARCORE_EXPORT FormFieldChoice : public FormField
             ListBox       ///< A list box choice field.
         };
 
-        virtual ~FormFieldChoice();
+        ~FormFieldChoice() override;
 
         /**
          * The particular type of the choice field.
@@ -387,6 +427,46 @@ class OKULARCORE_EXPORT FormFieldChoice : public FormField
         Q_DISABLE_COPY( FormFieldChoice )
 };
 
+/**
+ * @short Interface of a signature form field.
+ *
+ * This is the base interface to reimplement to represent a signature field.
+ */
+class OKULARCORE_EXPORT FormFieldSignature : public FormField
+{
+    public:
+        /**
+         * The types of signature.
+         */
+        enum SignatureType {
+            AdbePkcs7sha1,
+            AdbePkcs7detached,
+            EtsiCAdESdetached,
+            UnknownType
+         };
+
+        ~FormFieldSignature() override;
+
+        /**
+         * The signature type
+         */
+        virtual SignatureType signatureType() const = 0;
+
+        /**
+         * The signature info
+         */
+        virtual const SignatureInfo &signatureInfo() const = 0;
+
+    protected:
+        FormFieldSignature();
+
+    private:
+        Q_DECLARE_PRIVATE( FormFieldSignature )
+        Q_DISABLE_COPY( FormFieldSignature )
+};
+
 }
 
+Q_DECLARE_METATYPE(const Okular::FormFieldSignature *);
+
 #endif
