@@ -68,7 +68,7 @@ PixmapGenerationThread* GeneratorPrivate::pixmapGenerationThread()
 
     Q_Q( Generator );
     mPixmapGenerationThread = new PixmapGenerationThread( q );
-    QObject::connect( mPixmapGenerationThread, SIGNAL(finished()), q, SLOT(pixmapGenerationFinished()),
+    QObject::connect( mPixmapGenerationThread, &PixmapGenerationThread::finished, q, [this] { pixmapGenerationFinished(); },
                       Qt::QueuedConnection );
 
     return mPixmapGenerationThread;
@@ -81,7 +81,7 @@ TextPageGenerationThread* GeneratorPrivate::textPageGenerationThread()
 
     Q_Q( Generator );
     mTextPageGenerationThread = new TextPageGenerationThread( q );
-    QObject::connect( mTextPageGenerationThread, SIGNAL(finished()), q, SLOT(textpageGenerationFinished()),
+    QObject::connect( mTextPageGenerationThread, &TextPageGenerationThread::finished, q, [this] { textpageGenerationFinished(); },
                       Qt::QueuedConnection );
 
     return mTextPageGenerationThread;
@@ -518,7 +518,7 @@ void Generator::requestFontData(const Okular::FontInfo & /*font*/, QByteArray *
 
 }
 
-void Generator::setDPI(const QSizeF & dpi)
+void Generator::setDPI(const QSizeF & dpi) // clazy:exclude=function-args-by-value TODO remove the & when we do a BIC change elsewhere
 {
      Q_D( Generator );
      d->m_dpi = dpi;
@@ -807,6 +807,4 @@ QDebug operator<<( QDebug str, const Okular::PixmapRequest &req )
     return str;
 }
 
-#include "moc_generator.cpp"
-
 /* kate: replace-tabs on; indent-width 4; */
