@@ -134,8 +134,8 @@ QTransform PagePrivate::rotationMatrix() const
 
 /** class Page **/
 
-Page::Page( uint page, double w, double h, Rotation o )
-    : d( new PagePrivate( this, page, w, h, o ) )
+Page::Page( uint pageNumber, double w, double h, Rotation o )
+    : d( new PagePrivate( this, pageNumber, w, h, o ) )
 {
 }
 
@@ -358,10 +358,10 @@ TextEntity::List Page::words( const RegularAreaRect * area, TextPage::TextAreaIn
     else
         ret = d->m_text->words( nullptr, b );
 
-    for (int i = 0; i < ret.length(); ++i)
+    for (auto &retI : ret)
     {
-        const TextEntity * orig = ret[i];
-        ret[i] = new TextEntity( orig->text(), new Okular::NormalizedRect(orig->transformedArea ( d->rotationMatrix() )) );
+        const TextEntity * orig = retI;
+        retI = new TextEntity( orig->text(), new Okular::NormalizedRect(orig->transformedArea ( d->rotationMatrix() )) );
         delete orig;
     }
 
@@ -411,15 +411,13 @@ void PagePrivate::rotateAt( Rotation orientation )
      * Rotate the object rects on the page.
      */
     const QTransform matrix = rotationMatrix();
-    QLinkedList< ObjectRect * >::const_iterator objectIt = m_page->m_rects.begin(), end = m_page->m_rects.end();
-    for ( ; objectIt != end; ++objectIt )
-        (*objectIt)->transform( matrix );
+    for ( ObjectRect *objRect : qAsConst(m_page->m_rects) )
+        objRect->transform( matrix );
 
     const QTransform highlightRotationMatrix = Okular::buildRotationMatrix( (Rotation)(((int)m_rotation - (int)oldRotation + 4) % 4) );
-    QLinkedList< HighlightAreaRect* >::const_iterator hlIt = m_page->m_highlights.begin(), hlItEnd = m_page->m_highlights.end();
-    for ( ; hlIt != hlItEnd; ++hlIt )
+    for ( HighlightAreaRect *hlar : qAsConst(m_page->m_highlights) )
     {
-        (*hlIt)->transform( highlightRotationMatrix );
+        hlar->transform( highlightRotationMatrix );
     }
 }
 
@@ -506,7 +504,7 @@ QLinkedList< Annotation* > Page::annotations() const
 
 Annotation * Page::annotation( const QString & uniqueName ) const
 {
-    foreach(Annotation *a, m_annotations)
+    for (Annotation *a : m_annotations)
     {
         if ( a->uniqueName() == uniqueName )
             return a;
@@ -633,8 +631,9 @@ void PagePrivate::setTextSelections( RegularAreaRect *r, const QColor & color )
 void Page::setSourceReferences( const QLinkedList< SourceRefObjectRect * > & refRects )
 {
     deleteSourceReferences();
-    foreach( SourceRefObjectRect * rect, refRects )
+    for ( SourceRefObjectRect *rect : refRects ) {
         m_rects << rect;
+    }
 }
 
 void Page::setDuration( double seconds )
@@ -741,10 +740,9 @@ void Page::setFormFields( const QLinkedList< FormField * >& fields )
 {
     qDeleteAll( d->formfields );
     d->formfields = fields;
-    QLinkedList< FormField * >::const_iterator it = d->formfields.begin(), itEnd = d->formfields.end();
-    for ( ; it != itEnd; ++it )
+    for ( FormField *ff : qAsConst(d->formfields) )
     {
-        (*it)->d_ptr->setDefault();
+        ff->d_ptr->setDefault();
     }
 }
 
@@ -818,9 +816,7 @@ void Page::deleteAnnotations()
     // delete ObjectRects of type Annotation
     deleteObjectRects( m_rects, QSet<ObjectRect::ObjectType>() << ObjectRect::OAnnotation );
     // delete all stored annotations
-    QLinkedList< Annotation * >::const_iterator aIt = m_annotations.begin(), aEnd = m_annotations.end();
-    for ( ; aIt != aEnd; ++aIt )
-        delete *aIt;
+    qDeleteAll( m_annotations );
     m_annotations.clear();
 }
 
@@ -882,10 +878,9 @@ bool PagePrivate::restoreLocalContents( const QDomNode & pageNode )
                 continue;
 
             QHash<int, FormField*> hashedforms;
-            QLinkedList< FormField * >::const_iterator fIt = formfields.begin(), fItEnd = formfields.end();
-            for ( ; fIt != fItEnd; ++fIt )
+            for ( FormField *ff : qAsConst(formfields) )
             {
-                hashedforms[(*fIt)->id()] = (*fIt);
+                hashedforms[ff->id()] = ff;
             }
 
             // iterate over all forms
@@ -1102,19 +1097,19 @@ FormField *PagePrivate::findEquivalentForm( const Page *p, FormField *oldField )
 {
     // given how id is not very good of id (at least for pdf) we do a few passes
     // same rect, type and id
-    foreach(FormField *f, p->d->formfields)
+    for (FormField *f : qAsConst(p->d->formfields))
     {
         if (f->rect() == oldField->rect() && f->type() == oldField->type() && f->id() == oldField->id())
             return f;
     }
     // same rect and type
-    foreach(FormField *f, p->d->formfields)
+    for (FormField *f : qAsConst(p->d->formfields))
     {
         if (f->rect() == oldField->rect() && f->type() == oldField->type())
             return f;
     }
     // fuzzy rect, same type and id
-    foreach(FormField *f, p->d->formfields)
+    for (FormField *f : qAsConst(p->d->formfields))
     {
         if (f->type() == oldField->type() && f->id() == oldField->id() && qFuzzyCompare(f->rect().left, oldField->rect().left) && qFuzzyCompare(f->rect().top, oldField->rect().top) && qFuzzyCompare(f->rect().right, oldField->rect().right) && qFuzzyCompare(f->rect().bottom, oldField->rect().bottom))
         {
@@ -1122,7 +1117,7 @@ FormField *PagePrivate::findEquivalentForm( const Page *p, FormField *oldField )
         }
     }
     // fuzzy rect and same type
-    foreach(FormField *f, p->d->formfields)
+    for (FormField *f : qAsConst(p->d->formfields))
     {
         if (f->type() == oldField->type() && qFuzzyCompare(f->rect().left, oldField->rect().left) && qFuzzyCompare(f->rect().top, oldField->rect().top) && qFuzzyCompare(f->rect().right, oldField->rect().right) && qFuzzyCompare(f->rect().bottom, oldField->rect().bottom))
         {
