@@ -94,7 +94,7 @@ static bool segmentsOverlap(double left1, double right1, double left2, double ri
     return false;
 }
 
-static bool doesConsumeY(const QRect& first, const QRect& second, int threshold)
+static bool doesConsumeY(const QRect first, const QRect second, int threshold)
 {
     return segmentsOverlap(first.top(), first.bottom(), second.top(), second.bottom(), threshold);
 }
@@ -118,14 +118,14 @@ static bool doesConsumeY(const NormalizedRect& first, const NormalizedRect& seco
  */
 class TinyTextEntity
 {
-    static const int MaxStaticChars = sizeof( QChar * ) / sizeof( QChar );
+    static const int MaxStaticChars = sizeof( void* ) / sizeof( QChar );
 
     public:
         TinyTextEntity( const QString &text, const NormalizedRect &rect )
             : area( rect )
         {
             Q_ASSERT_X( !text.isEmpty(), "TinyTextEntity", "empty string" );
-            Q_ASSERT_X( sizeof( d ) == sizeof( QChar * ), "TinyTextEntity",
+            Q_ASSERT_X( sizeof( d ) == sizeof( void * ), "TinyTextEntity",
                         "internal storage is wider than QChar*, fix it!" );
             length = text.length();
             switch ( length )
@@ -290,7 +290,7 @@ public:
     {
     };
 
-    RegionText(const WordsWithCharacters &wordsWithCharacters, const QRect &area)
+    RegionText(const WordsWithCharacters &wordsWithCharacters, const QRect area)
         : m_region_wordWithCharacters(wordsWithCharacters), m_area(area)
     {
     }
@@ -298,8 +298,9 @@ public:
     inline QString string() const
     {
         QString res;
-        foreach(const WordWithCharacters &word, m_region_wordWithCharacters)
+        for (const WordWithCharacters &word : m_region_wordWithCharacters) {
             res += word.text();
+        }
         return res;
     }
 
@@ -313,7 +314,7 @@ public:
         return m_area;
     }
 
-    inline void setArea(const QRect &area)
+    inline void setArea(const QRect area)
     {
         m_area = area;
     }
@@ -1192,7 +1193,7 @@ static WordsWithCharacters makeWordFromCharacters(const TextList &characters, in
 
         while (!space)
         {
-            if (textString.length())
+            if (!textString.isEmpty())
             {
                 newString.append(textString);
 
@@ -1306,13 +1307,13 @@ QList< QPair<WordsWithCharacters, QRect> > makeAndSortLines(const WordsWithChara
         const QRect elementArea = (*it).area().roundedGeometry(pageWidth,pageHeight);
         bool found = false;
 
-        for( int i = 0 ; i < lines.length() ; i++)
+        for( QPair<WordsWithCharacters, QRect> &linesI : lines)
         {
             /* the line area which will be expanded
                line_rects is only necessary to preserve the topmin and bottommax of all
                the texts in the line, left and right is not necessary at all
             */
-            QRect &lineArea = lines[i].second;
+            QRect &lineArea = linesI.second;
             const int text_y1 = elementArea.top() ,
                       text_y2 = elementArea.top() + elementArea.height() ,
                       text_x1 = elementArea.left(),
@@ -1328,7 +1329,7 @@ QList< QPair<WordsWithCharacters, QRect> > makeAndSortLines(const WordsWithChara
              */
             if(doesConsumeY(elementArea,lineArea,70))
             {
-                WordsWithCharacters &line = lines[i].first;
+                WordsWithCharacters &line = linesI.first;
                 line.append(*it);
 
                 const int newLeft = line_x1 < text_x1 ? line_x1 : text_x1;
@@ -1355,9 +1356,9 @@ QList< QPair<WordsWithCharacters, QRect> > makeAndSortLines(const WordsWithChara
     }
 
     // Step 3
-    for(int i = 0 ; i < lines.length() ; i++)
+    for(QPair<WordsWithCharacters, QRect> &line : lines)
     {
-        WordsWithCharacters &list = lines[i].first;
+        WordsWithCharacters &list = line.first;
         std::sort(list.begin(), list.end(), compareTinyTextEntityX);
     }
     
@@ -1420,12 +1421,12 @@ static void calculateStatisticalInformation(const QList<WordWithCharacters> &wor
     QMap<int,int> hor_space_stat;
     QMap<int,int> col_space_stat;
     QList< QList<QRect> > space_rects;
-    QList<QRect> max_hor_space_rects;
+    QVector<QRect> max_hor_space_rects;
 
     // Space in every line
-    for(int i = 0 ; i < sortedLines.length() ; i++)
+    for(const QPair<WordsWithCharacters, QRect> &sortedLine : sortedLines)
     {
-        const WordsWithCharacters list = sortedLines.at(i).first;
+        const WordsWithCharacters list = sortedLine.first;
         QList<QRect> line_space_rects;
         int maxSpace = 0, minSpace = pageWidth;
 
@@ -1585,9 +1586,9 @@ static RegionTextList XYCutForBoundingBoxes(const QList<WordWithCharacters> &wor
         int count;
 
         // for every text in the region
-        for(int j = 0 ; j < list.length() ; ++j )
+        for( const WordWithCharacters &wwc : list )
         {
-            TinyTextEntity *ent = list.at(j).word;
+            TinyTextEntity *ent = wwc.word;
             const QRect entRect = ent->area.geometry(pageWidth, pageHeight);
 
             // calculate vertical projection profile proj_on_xaxis1
@@ -1758,9 +1759,8 @@ static RegionTextList XYCutForBoundingBoxes(const QList<WordWithCharacters> &wor
         // horizontal cut, topRect and bottomRect
         if(cut_hor)
         {
-            for( int j = 0 ; j < list.length() ; ++j )
+            for( const WordWithCharacters &word : list )
             {
-                const WordWithCharacters &word = list.at(j);
                 const QRect wordRect = word.area().geometry(pageWidth,pageHeight);
 
                 if(topRect.intersects(wordRect))
@@ -1779,9 +1779,8 @@ static RegionTextList XYCutForBoundingBoxes(const QList<WordWithCharacters> &wor
         //vertical cut, leftRect and rightRect
         else if(cut_ver)
         {
-            for( int j = 0 ; j < list.length() ; ++j )
+            for( const WordWithCharacters &word : list )
             {
-                const WordWithCharacters &word = list.at(j);
                 const QRect wordRect = word.area().geometry(pageWidth,pageHeight);
 
                 if(leftRect.intersects(wordRect))
@@ -1813,17 +1812,15 @@ WordsWithCharacters addNecessarySpace(RegionTextList tree, int pageWidth, int pa
      */
 
     // Only change the texts under RegionTexts, not the area
-    for(int j = 0 ; j < tree.length() ; j++)
+    for(RegionText &tmpRegion : tree)
     {
-        RegionText &tmpRegion = tree[j];
-
         // Step 01
         QList< QPair<WordsWithCharacters, QRect> > sortedLines = makeAndSortLines(tmpRegion.text(), pageWidth, pageHeight);
 
         // Step 02
-        for(int i = 0 ; i < sortedLines.length() ; i++)
+        for(QPair<WordsWithCharacters, QRect> &sortedLine : sortedLines)
         {
-            WordsWithCharacters &list = sortedLines[i].first;
+            WordsWithCharacters &list = sortedLine.first;
             for(int k = 0 ; k < list.length() ; k++ )
             {
                 const QRect area1 = list.at(k).area().roundedGeometry(pageWidth,pageHeight);
@@ -1856,18 +1853,18 @@ WordsWithCharacters addNecessarySpace(RegionTextList tree, int pageWidth, int pa
         }
 
         WordsWithCharacters tmpList;
-        for(int i = 0 ; i < sortedLines.length() ; i++)
+        for(const QPair<WordsWithCharacters, QRect> &sortedLine : qAsConst(sortedLines))
         {
-            tmpList += sortedLines.at(i).first;
+            tmpList += sortedLine.first;
         }
         tmpRegion.setText(tmpList);
     }
 
     // Step 03
     WordsWithCharacters tmp;
-    for(int i = 0 ; i < tree.length() ; i++)
+    for(const RegionText &tmpRegion : qAsConst(tree))
     {
-        tmp += tree.at(i).text();
+        tmp += tmpRegion.text();
     }
     return tmp;
 }
@@ -1911,7 +1908,7 @@ void TextPagePrivate::correctTextOrder()
      * Break the words into characters
      */
     TextList listOfCharacters;
-    foreach(const WordWithCharacters &word, listWithWordsAndSpaces)
+    for (const WordWithCharacters &word : listWithWordsAndSpaces)
     {
         delete word.word;
         listOfCharacters.append(word.characters);
@@ -1927,7 +1924,7 @@ TextEntity::List TextPage::words(const RegularAreaRect *area, TextAreaInclusionB
     TextEntity::List ret;
     if ( area )
     {
-        foreach (TinyTextEntity *te, d->m_words)
+        for (const TinyTextEntity *te : qAsConst(d->m_words))
         {
             if (b == AnyPixelTextAreaInclusionBehaviour)
             {
@@ -1948,7 +1945,7 @@ TextEntity::List TextPage::words(const RegularAreaRect *area, TextAreaInclusionB
     }
     else
     {
-        foreach (TinyTextEntity *te, d->m_words)
+        for (const TinyTextEntity *te : qAsConst(d->m_words))
         {
             ret.append( new TextEntity( te->text(), new Okular::NormalizedRect( te->area) ) );
         }
