@@ -25,7 +25,7 @@ class HelperXmlHandler_EpubContainer : public QXmlDefaultHandler
 {
 	public:
 		// Overridden members
-		bool startElement ( const QString & namespaceURI, const QString & localName, const QString & qName, const QXmlAttributes & atts );
+		bool startElement ( const QString & namespaceURI, const QString & localName, const QString & qName, const QXmlAttributes & atts ) override;
 
 		// The content path
 		QString	contentPath;
