@@ -26,34 +26,34 @@ HelperXmlHandler_EpubContent::HelperXmlHandler_EpubContent()
 bool HelperXmlHandler_EpubContent::startElement(const QString &, const QString &localName, const QString &, const QXmlAttributes &atts)
 {
 	// <metadata> tag contains the medatada which goes into m_metadata
-	if ( localName == "metadata" )
+	if ( localName == QLatin1String("metadata") )
 		m_state = STATE_IN_METADATA;
-	else if ( localName == "manifest" )
+	else if ( localName == QLatin1String("manifest") )
 		m_state = STATE_IN_MANIFEST;
-	else if ( localName == "spine" )
+	else if ( localName == QLatin1String("spine") )
 		m_state = STATE_IN_SPINE;
 	// Now handle the states
 	else if ( m_state == STATE_IN_METADATA ) // we don't need to store the first 'metadata' here
 		m_tagname = localName;
-	else if ( m_state == STATE_IN_MANIFEST && localName == "item" )
+	else if ( m_state == STATE_IN_MANIFEST && localName == QLatin1String("item") )
 	{
-		int idx_id = atts.index( "id" );
-		int idx_href = atts.index( "href" );
-		int idx_mtype = atts.index( "media-type" );
+		int idx_id = atts.index( QLatin1String("id") );
+		int idx_href = atts.index( QLatin1String("href") );
+		int idx_mtype = atts.index( QLatin1String("media-type") );
 
 		if ( idx_id == -1 || idx_href == -1 || idx_mtype == -1 )
 			return false;
 
 		manifest[ atts.value( idx_id ) ] = atts.value( idx_href );
 
-		if ( atts.value( idx_mtype ) == "application/x-dtbncx+xml" )
+		if ( atts.value( idx_mtype ) == QLatin1String("application/x-dtbncx+xml") )
 			tocname = atts.value( idx_href );
 
 		//qDebug() << "MANIFEST: " << atts.value( idx_id ) << "->" << atts.value( idx_href );
 	}
-	else if ( m_state == STATE_IN_SPINE && localName == "itemref" )
+	else if ( m_state == STATE_IN_SPINE && localName == QLatin1String("itemref") )
 	{
-		int idx = atts.index( "idref" );
+		int idx = atts.index( QLatin1String("idref") );
 
 		if ( idx == -1 )
 			return false;
@@ -86,7 +86,7 @@ bool HelperXmlHandler_EpubContent::characters(const QString &ch)
 
 bool HelperXmlHandler_EpubContent::endElement(const QString &, const QString &, const QString &qName)
 {
-	if ( qName == "manifest" || qName == "metadata" || qName == "spine" )
+	if ( qName == QLatin1String("manifest") || qName == QLatin1String("metadata") || qName == QLatin1String("spine") )
 		m_state = STATE_NONE;
 
 	return true;
