@@ -86,7 +86,7 @@ dvifile::dvifile(const dvifile *old, fontPool *fp)
   size_of_file = old->size_of_file;
   end_pointer = dvi_Data()+size_of_file;
   if (dvi_Data() == nullptr) {
-    qCCritical(OkularDviDebug) << "Not enough memory to copy the DVI-file." << endl;
+    qCCritical(OkularDviDebug) << "Not enough memory to copy the DVI-file.";
     return;
   }
 
@@ -242,7 +242,7 @@ void dvifile::prepare_pages()
 
   page_offset.resize(total_pages+1);
   if (page_offset.size() < (total_pages+1)) {
-    qCCritical(OkularDviDebug) << "No memory for page list!" << endl;
+    qCCritical(OkularDviDebug) << "No memory for page list!";
     return;
   }
   for(int i=0; i<=total_pages; i++)
