@@ -70,7 +70,7 @@ bool pageSize::setPageSize(const QString& name)
       // Set page width/height accordingly
       pageWidth.setLength_in_mm(staticList[currentSize].width);
       pageHeight.setLength_in_mm(staticList[currentSize].height);
-      emit(sizeChanged(*this));
+      emit sizeChanged(*this);
       return true;
     }
   }
@@ -88,7 +88,7 @@ bool pageSize::setPageSize(const QString& name)
 
       rectifySizes();
       reconstructCurrentSize();
-      emit(sizeChanged(*this));
+      emit sizeChanged(*this);
       return true;
     }
   }
@@ -106,7 +106,7 @@ bool pageSize::setPageSize(const QString& name)
 
       rectifySizes();
       reconstructCurrentSize();
-      emit(sizeChanged(*this));
+      emit sizeChanged(*this);
       return true;
     }
   }
@@ -117,7 +117,7 @@ bool pageSize::setPageSize(const QString& name)
   pageWidth.setLength_in_mm(staticList[currentSize].width);
   pageHeight.setLength_in_mm(staticList[currentSize].height);
   qCCritical(OkularDviShellDebug) << "pageSize::setPageSize: could not parse '" << name << "'. Using " << staticList[currentSize].name << " as a default." << endl;
-  emit(sizeChanged(*this));
+  emit sizeChanged(*this);
   return false;
 }
 
@@ -132,7 +132,7 @@ void pageSize::setPageSize(double width, double height)
   rectifySizes();
   reconstructCurrentSize();
   if ( !isNearlyEqual(oldPage))
-    emit(sizeChanged(*this));
+    emit sizeChanged(*this);
 }
 
 
@@ -168,24 +168,9 @@ void pageSize::setPageSize(const QString& width, const QString& _widthUnits, con
   rectifySizes();
   reconstructCurrentSize();
   if ( !isNearlyEqual(oldPage))
-    emit(sizeChanged(*this));
+    emit sizeChanged(*this);
 }
 
-
-pageSize &pageSize::operator= (const pageSize &src)
-{
-  SimplePageSize oldPage = *this;
-
-  currentSize = src.currentSize;
-  pageWidth   = src.pageWidth;
-  pageHeight  = src.pageHeight;
-
-  if ( !isNearlyEqual(oldPage))
-    emit(sizeChanged(*this));
-  return *this;
-}
-
-
 void pageSize::rectifySizes()
 {
   // Now do some sanity checks to make sure that values are not
@@ -293,7 +278,7 @@ void pageSize::setOrientation(int orient)
     pageWidth.setLength_in_mm(staticList[currentSize].width);
     pageHeight.setLength_in_mm(staticList[currentSize].height);
   }
-  emit(sizeChanged(*this));
+  emit sizeChanged(*this);
 }
 
 
