@@ -65,7 +65,7 @@ ghostscript_interface::~ghostscript_interface() {
 }
 
 
-void ghostscript_interface::setPostScript(const PageNumber& page, const QString& PostScript) {
+void ghostscript_interface::setPostScript(const PageNumber page, const QString& PostScript) {
 #ifdef DEBUG_PSGS
   qCDebug(OkularDviDebug) << "ghostscript_interface::setPostScript( " << page << ", ... )";
 #endif
@@ -89,7 +89,7 @@ void ghostscript_interface::setIncludePath(const QString &_includePath) {
 }
 
 
-void ghostscript_interface::setBackgroundColor(const PageNumber& page, const QColor& background_color, bool permanent) {
+void ghostscript_interface::setBackgroundColor(const PageNumber page, const QColor& background_color, bool permanent) {
 #ifdef DEBUG_PSGS
   qCDebug(OkularDviDebug) << "ghostscript_interface::setBackgroundColor( " << page << ", " << background_color << " )";
 #endif
@@ -110,7 +110,7 @@ void ghostscript_interface::setBackgroundColor(const PageNumber& page, const QCo
   }
 }
 
-void ghostscript_interface::restoreBackgroundColor(const PageNumber& page)
+void ghostscript_interface::restoreBackgroundColor(const PageNumber page)
 {
 #ifdef DEBUG_PSGS
   qCDebug(OkularDviDebug) << "ghostscript_interface::restoreBackgroundColor( " << page << " )";
@@ -125,7 +125,7 @@ void ghostscript_interface::restoreBackgroundColor(const PageNumber& page)
 // Returns the background color for a certain page. This color is
 // always guaranteed to be valid
 
-QColor ghostscript_interface::getBackgroundColor(const PageNumber& page) const {
+QColor ghostscript_interface::getBackgroundColor(const PageNumber page) const {
 #ifdef DEBUG_PSGS
   qCDebug(OkularDviDebug) << "ghostscript_interface::getBackgroundColor( " << page << " )";
 #endif
@@ -146,7 +146,7 @@ void ghostscript_interface::clear() {
 }
 
 
-void ghostscript_interface::gs_generate_graphics_file(const PageNumber& page, const QString& filename, long magnification) {
+void ghostscript_interface::gs_generate_graphics_file(const PageNumber page, const QString& filename, long magnification) {
 #ifdef DEBUG_PSGS
   qCDebug(OkularDviDebug) << "ghostscript_interface::gs_generate_graphics_file( " << page << ", " << filename << " )";
 #endif
@@ -293,7 +293,7 @@ void ghostscript_interface::gs_generate_graphics_file(const PageNumber& page, co
 }
 
 
-void ghostscript_interface::graphics(const PageNumber& page, double dpi, long magnification, QPainter* paint) {
+void ghostscript_interface::graphics(const PageNumber page, double dpi, long magnification, QPainter* paint) {
 #ifdef DEBUG_PSGS
   qCDebug(OkularDviDebug) << "ghostscript_interface::graphics( " << page << ", " << dpi << ", ... ) called.";
 #endif
