@@ -435,7 +435,7 @@ g31expand(pagenode *pn, drawfunc df)
 	for (EOLcnt = 1; !EndOfData(pn); EOLcnt++) {
 	    /* we have seen 11 zeros, which implies EOL,
 	       skip possible fill bits too */
-	    while (1) {
+	    while (true) {
 		NeedBits(8);
 		if (GetBits(8))
 		    break;
@@ -524,7 +524,7 @@ g32expand(pagenode *pn, drawfunc df)
 	for (EOLcnt = 1; !EndOfData(pn); EOLcnt++) {
 	    /* we have seen 11 zeros, which implies EOL,
 	       skip possible fill bits too */
-	    while (1) {
+	    while (true) {
 		NeedBits(8);
 		if (GetBits(8))
 		    break;
@@ -704,19 +704,19 @@ static const unsigned char zerotab[256] = {
     prezeros >>= 4;							\
     if (prezeros == 8) {						\
 	zeros += 8;							\
-	continue;							\
+	break;							\
     }									\
     if (zeros + prezeros < 11) {					\
 	empty = 0;							\
 	zeros = postzeros;						\
-	continue;							\
+	break;							\
     }									\
     zeros = postzeros;							\
     if (empty)								\
 	EOLcnt++;							\
     lines++;								\
     empty = 1;								\
-} while (0)
+} while (false)
 
 /* count fax lines */
 int
