@@ -128,8 +128,6 @@ class DummyCertificateInfo : public Okular::CertificateInfo
 
 #endif
 
-#ifdef HAVE_POPPLER_0_51
-
 PopplerSignatureInfo::PopplerSignatureInfo( const Poppler::SignatureValidationInfo &info )
     : m_info( info )
 {
@@ -193,7 +191,6 @@ PopplerSignatureInfo::CertificateStatus PopplerSignatureInfo::certificateStatus(
 
 PopplerSignatureInfo::HashAlgorithm PopplerSignatureInfo::hashAlgorithm() const
 {
-#ifdef HAVE_POPPLER_0_58
     switch ( m_info.hashAlgorithm() )
     {
         case Poppler::SignatureValidationInfo::HashAlgorithmMd2:
@@ -213,9 +210,6 @@ PopplerSignatureInfo::HashAlgorithm PopplerSignatureInfo::hashAlgorithm() const
         default:
             return HashAlgorithmUnknown;
     }
-#else
-    return HashAlgorithmUnknown;
-#endif
 }
 
 QString PopplerSignatureInfo::signerName() const
@@ -225,11 +219,7 @@ QString PopplerSignatureInfo::signerName() const
 
 QString PopplerSignatureInfo::signerSubjectDN() const
 {
-#ifdef HAVE_POPPLER_0_58
     return m_info.signerSubjectDN();
-#else
-    return {};
-#endif
 }
 
 QString PopplerSignatureInfo::location() const
@@ -257,34 +247,20 @@ QDateTime PopplerSignatureInfo::signingTime() const
 
 QByteArray PopplerSignatureInfo::signature() const
 {
-#ifdef HAVE_POPPLER_0_58
     return m_info.signature();
-#else
-    return {};
-#endif
 }
 
 QList<qint64> PopplerSignatureInfo::signedRangeBounds() const
 {
-#ifdef HAVE_POPPLER_0_58
     return m_info.signedRangeBounds();
-#else
-    return {};
-#endif
 }
 
 bool PopplerSignatureInfo::signsTotalDocument() const
 {
- #ifdef HAVE_POPPLER_0_58
     return m_info.signsTotalDocument();
-#else
-    return false;
-#endif
 }
 
 const Okular::CertificateInfo &PopplerSignatureInfo::certificateInfo() const
 {
     return *m_certfiticateInfo;
 }
-
-#endif
