@@ -168,7 +168,7 @@ static bool nextAbbPathToken(AbbPathToken *token)
 /**
     Read point (two reals delimited by comma) from abbreviated path data
 */
-static QPointF getPointFromString(AbbPathToken *token, bool relative, const QPointF &currentPosition) {
+static QPointF getPointFromString(AbbPathToken *token, bool relative, const QPointF currentPosition) {
     //TODO Check grammar
 
     QPointF result;
@@ -508,7 +508,7 @@ static QByteArray readFileOrDirectoryParts( const KArchiveEntry *entry, QString
         const KArchiveDirectory* relDir = static_cast<const KArchiveDirectory *>( entry );
         QStringList entries = relDir->entries();
         std::sort(entries.begin(), entries.end());
-        Q_FOREACH ( const QString &entry, entries ) {
+        for ( const QString &entry : qAsConst(entries) ) {
             const KArchiveEntry* relSubEntry = relDir->entry( entry );
             if ( !relSubEntry->isFile() )
                 continue;
@@ -553,7 +553,7 @@ static const KArchiveEntry* loadEntry( KZip *archive, const QString &fileName, Q
         const KArchiveDirectory* relDir = static_cast< const KArchiveDirectory * >( newEntry );
         QStringList relEntries = relDir->entries();
         std::sort(relEntries.begin(), relEntries.end());
-        Q_FOREACH ( const QString &relEntry, relEntries ) {
+        for ( const QString &relEntry : qAsConst(relEntries) ) {
             if ( relEntry.compare( entryName, Qt::CaseInsensitive ) == 0 ) {
                 return relDir->entry( relEntry );
             }
@@ -606,7 +606,7 @@ static bool xpsGradientLessThan( const XpsGradient &g1, const XpsGradient &g2 )
 static int xpsGradientWithOffset( const QList<XpsGradient> &gradients, double offset )
 {
     int i = 0;
-    Q_FOREACH ( const XpsGradient &grad, gradients ) {
+    for ( const XpsGradient &grad : gradients ) {
         if ( grad.offset == offset ) {
             return i;
         }
@@ -686,7 +686,7 @@ static void preprocessXpsGradients( QList<XpsGradient> &gradients )
 
 static void addXpsGradientsToQGradient( const QList<XpsGradient> &gradients, QGradient *qgrad )
 {
-    Q_FOREACH ( const XpsGradient &grad, gradients ) {
+    for ( const XpsGradient &grad : gradients ) {
         qgrad->setColorAt( grad.offset, grad.color );
     }
 }
@@ -1121,7 +1121,7 @@ void XpsHandler::processPath( XpsRenderNode &node )
         m_painter->setWorldTransform( pathdata->transform, true );
     }
 
-    Q_FOREACH ( XpsPathFigure *figure, pathdata->paths ) {
+    for ( const XpsPathFigure *figure : qAsConst(pathdata->paths) ) {
         m_painter->setBrush( figure->isFilled ? brush : QBrush() );
         m_painter->drawPath( figure->path );
     }
@@ -1144,7 +1144,7 @@ void XpsHandler::processPathGeometry( XpsRenderNode &node )
 {
     XpsPathGeometry * geom = new XpsPathGeometry();
 
-    Q_FOREACH ( const XpsRenderNode &child, node.children ) {
+    for ( const XpsRenderNode &child : qAsConst(node.children) ) {
         if ( child.data.canConvert<XpsPathFigure *>() ) {
             XpsPathFigure *figure = child.data.value<XpsPathFigure *>();
             geom->paths.append( figure );
@@ -1194,7 +1194,7 @@ void XpsHandler::processPathFigure( XpsRenderNode &node )
         return;
     }
 
-    Q_FOREACH ( const XpsRenderNode &child, node.children ) {
+    for ( const XpsRenderNode &child : qAsConst(node.children) ) {
         bool isStroked = true;
         att = node.attributes.value( QStringLiteral("IsStroked") );
         if ( !att.isEmpty() ) {
@@ -1209,7 +1209,7 @@ void XpsHandler::processPathFigure( XpsRenderNode &node )
             att = child.attributes.value( QStringLiteral("Points") );
             if ( !att.isEmpty() ) {
                 const QStringList points = att.split( QLatin1Char( ' ' ), QString::SkipEmptyParts );
-                Q_FOREACH ( const QString &p, points ) {
+                for ( const QString &p : points ) {
                     QPointF point = getPointFromString( p );
                     path.lineTo( point );
                 }
@@ -1316,7 +1316,7 @@ void XpsHandler::processEndElement( XpsRenderNode &node )
     } else if (node.name == QLatin1String("ImageBrush.Transform")) {
         node.data = node.getRequiredChildData( QStringLiteral("MatrixTransform") );
     } else if (node.name == QLatin1String("LinearGradientBrush")) {
-        XpsRenderNode * gradients = node.findChild( QStringLiteral("LinearGradientBrush.GradientStops") );
+        const XpsRenderNode * gradients = node.findChild( QStringLiteral("LinearGradientBrush.GradientStops") );
         if ( gradients && gradients->data.canConvert< QGradient * >() ) {
             QPointF start = getPointFromString( node.attributes.value( QStringLiteral("StartPoint") ) );
             QPointF end = getPointFromString( node.attributes.value( QStringLiteral("EndPoint") ) );
@@ -1328,7 +1328,7 @@ void XpsHandler::processEndElement( XpsRenderNode &node )
             delete qgrad;
         }
     } else if (node.name == QLatin1String("RadialGradientBrush")) {
-        XpsRenderNode * gradients = node.findChild( QStringLiteral("RadialGradientBrush.GradientStops") );
+        const XpsRenderNode * gradients = node.findChild( QStringLiteral("RadialGradientBrush.GradientStops") );
         if ( gradients && gradients->data.canConvert< QGradient * >() ) {
             QPointF center = getPointFromString( node.attributes.value( QStringLiteral("Center") ) );
             QPointF origin = getPointFromString( node.attributes.value( QStringLiteral("GradientOrigin") ) );
@@ -1345,7 +1345,7 @@ void XpsHandler::processEndElement( XpsRenderNode &node )
         }
     } else if (node.name == QLatin1String("LinearGradientBrush.GradientStops")) {
         QList<XpsGradient> gradients;
-        Q_FOREACH ( const XpsRenderNode &child, node.children ) {
+        for ( const XpsRenderNode &child : qAsConst(node.children) ) {
             double offset = child.attributes.value( QStringLiteral("Offset") ).toDouble();
             QColor color = hexToRgba( child.attributes.value( QStringLiteral("Color") ).toLatin1() );
             gradients.append( XpsGradient( offset, color ) );
@@ -1358,7 +1358,7 @@ void XpsHandler::processEndElement( XpsRenderNode &node )
         }
     } else if (node.name == QLatin1String("RadialGradientBrush.GradientStops")) {
         QList<XpsGradient> gradients;
-        Q_FOREACH ( const XpsRenderNode &child, node.children ) {
+        for ( const XpsRenderNode &child : qAsConst(node.children) ) {
             double offset = child.attributes.value( QStringLiteral("Offset") ).toDouble();
             QColor color = hexToRgba( child.attributes.value( QStringLiteral("Color") ).toLatin1() );
             gradients.append( XpsGradient( offset, color ) );
@@ -1729,7 +1729,7 @@ void XpsDocument::parseDocumentStructure( const QString &documentStructureFileNa
                 synopsisElement.setAttribute( QStringLiteral("Viewport"),  viewport.toString() );
                 if ( outlineLevel == 1 ) {
                     // qCWarning(OkularXpsDebug) << "Description: "
-                    // << outlineEntryElement.attribute( "Description" ) << endl;
+                    // << outlineEntryElement.attribute( "Description" );
                     m_docStructure->appendChild( synopsisElement );
                 } else {
                     // find the last next highest element (so it this is level 3, we need
@@ -1827,14 +1827,14 @@ XpsDocument::XpsDocument(XpsFile *file, const QString &fileName): m_file(file),
                 } else {
                     qCWarning(OkularXpsDebug) << "Unknown document relationships element: "
                                      << attributes.value( QStringLiteral("Type") ).toString() << " : "
-                                     << attributes.value( QStringLiteral("Target") ).toString() << endl;
+                                     << attributes.value( QStringLiteral("Target") ).toString();
                 }
             }
         }
         if ( xml.error() ) {
             qCWarning(OkularXpsDebug) << "Could not parse XPS page relationships file ( "
                              << documentRelationshipFile
-                             << " ) - " << xml.errorString() << endl;
+                             << " ) - " << xml.errorString();
         }
     } else { // the page relationship file didn't exist in the zipfile
         // this isn't fatal
@@ -1854,9 +1854,7 @@ XpsDocument::XpsDocument(XpsFile *file, const QString &fileName): m_file(file),
 
 XpsDocument::~XpsDocument()
 {
-    for (int i = 0; i < m_pages.size(); i++) {
-        delete m_pages.at( i );
-    }
+    qDeleteAll(m_pages);
     m_pages.clear();
 
     if ( m_docStructure )
@@ -2203,20 +2201,20 @@ bool XpsGenerator::print( QPrinter &printer )
     return true;
 }
 
-XpsRenderNode * XpsRenderNode::findChild( const QString &name )
+const XpsRenderNode * XpsRenderNode::findChild( const QString &name ) const
 {
-    for (int i = 0; i < children.size(); i++) {
-        if (children[i].name == name) {
-            return &children[i];
+    for (const XpsRenderNode &child : children) {
+        if (child.name == name) {
+            return &child;
         }
     }
 
     return nullptr;
 }
 
-QVariant XpsRenderNode::getRequiredChildData( const QString &name )
+QVariant XpsRenderNode::getRequiredChildData( const QString &name ) const
 {
-    XpsRenderNode * child = findChild( name );
+    const XpsRenderNode * child = findChild( name );
     if (child == nullptr) {
         qCWarning(OkularXpsDebug) << "Required element " << name << " is missing in " << this->name;
         return QVariant();
@@ -2225,9 +2223,9 @@ QVariant XpsRenderNode::getRequiredChildData( const QString &name )
     return child->data;
 }
 
-QVariant XpsRenderNode::getChildData( const QString &name )
+QVariant XpsRenderNode::getChildData( const QString &name ) const
 {
-    XpsRenderNode * child = findChild( name );
+    const XpsRenderNode * child = findChild( name );
     if (child == nullptr) {
         return QVariant();
     } else {
