@@ -23,7 +23,7 @@
 
 #include <QList>
 #include <QTimer>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QApplication>
 #include <QContextMenuEvent>
 #include <QHBoxLayout>
@@ -34,7 +34,6 @@
 #include <QTreeView>
 
 #include <QDebug>
-#include <kiconloader.h>
 #include <KLocalizedString>
 #include <ktoolbar.h>
 
@@ -60,7 +59,7 @@ class KTreeViewSearchLine::Private
     int queuedSearches;
 
     void rowsInserted(const QModelIndex & parent, int start, int end) const;
-    void treeViewDeleted( QObject *treeView );
+    void treeViewDeleted( QObject *object );
     void slotCaseSensitive();
     void slotRegularExpression();
 
@@ -220,10 +219,10 @@ void KTreeViewSearchLine::updateSearch( QTreeView *treeView )
     treeView->scrollTo( currentIndex );
 }
 
-void KTreeViewSearchLine::setCaseSensitivity( Qt::CaseSensitivity caseSensitive )
+void KTreeViewSearchLine::setCaseSensitivity( Qt::CaseSensitivity caseSensitivity )
 {
-  if ( d->caseSensitive != caseSensitive ) {
-    d->caseSensitive = caseSensitive;
+  if ( d->caseSensitive != caseSensitivity ) {
+    d->caseSensitive = caseSensitivity;
     updateSearch();
     emit searchOptionsChanged();
   }
@@ -260,18 +259,21 @@ bool KTreeViewSearchLine::itemMatches( const QModelIndex &parentIndex, int row,
     return false;
 
   // Construct a regular expression object with the right options.
-  QRegExp expression = QRegExp( pattern,
-      d->caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive,
-      d->regularExpression ? QRegExp::RegExp : QRegExp::FixedString );
+  QRegularExpression re(
+      d->regularExpression ? pattern : QRegularExpression::escape(pattern),
+      d->caseSensitive ? QRegularExpression::NoPatternOption : QRegularExpression::CaseInsensitiveOption );
+  QRegularExpressionMatch match;
 
   // If the search column list is populated, search just the columns
   // specified.  If it is empty default to searching all of the columns.
-
   QAbstractItemModel *model = d->treeView->model();
   const int columncount = model->columnCount( parentIndex );
   for ( int i = 0; i < columncount; ++i) {
-    if ( expression.indexIn( model->data( model->index( row, i, parentIndex ), Qt::DisplayRole ).toString() ) >= 0 )
-      return true;
+    const QString str = model->data( model->index( row, i, parentIndex ), Qt::DisplayRole ).toString();
+    match = re.match( str );
+    if ( match.hasMatch() ) {
+        return true;
+    }
   }
 
   return false;
@@ -283,10 +285,10 @@ void KTreeViewSearchLine::contextMenuEvent( QContextMenuEvent *event )
 
   popup->addSeparator();
   QMenu *optionsSubMenu = popup->addMenu( i18n("Search Options") );
-  QAction* caseSensitiveAction = optionsSubMenu->addAction( i18nc("Enable case sensitive search in the side navigation panels", "Case Sensitive"), this, SLOT(slotCaseSensitive()) );
+  QAction* caseSensitiveAction = optionsSubMenu->addAction( i18nc("Enable case sensitive search in the side navigation panels", "Case Sensitive"), this, [this] { d->slotCaseSensitive(); } );
   caseSensitiveAction->setCheckable( true );
   caseSensitiveAction->setChecked( d->caseSensitive );
-  QAction* regularExpressionAction = optionsSubMenu->addAction( i18nc("Enable regular expression search in the side navigation panels", "Regular Expression"), this, SLOT(slotRegularExpression()) );
+  QAction* regularExpressionAction = optionsSubMenu->addAction( i18nc("Enable regular expression search in the side navigation panels", "Regular Expression"), this, [this] { d->slotRegularExpression(); } );
   regularExpressionAction->setCheckable( true );
   regularExpressionAction->setChecked( d->regularExpression );
 
@@ -297,22 +299,22 @@ void KTreeViewSearchLine::contextMenuEvent( QContextMenuEvent *event )
 void KTreeViewSearchLine::connectTreeView( QTreeView *treeView )
 {
   if ( treeView ) {
-    connect( treeView, SIGNAL(destroyed(QObject*)),
-             this, SLOT(treeViewDeleted(QObject*)) );
+    connect( treeView, &QTreeView::destroyed,
+                this, &KTreeViewSearchLine::treeViewDeleted );
 
-    connect( treeView->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-             this, SLOT(rowsInserted(QModelIndex,int,int)) );
+    connect( treeView->model(), &QAbstractItemModel::rowsInserted,
+             this, &KTreeViewSearchLine::rowsInserted );
   }
 }
 
 void KTreeViewSearchLine::disconnectTreeView( QTreeView *treeView )
 {
   if ( treeView ) {
-    disconnect( treeView, SIGNAL(destroyed(QObject*)),
-                this, SLOT(treeViewDeleted(QObject*)) );
+    disconnect( treeView, &QTreeView::destroyed,
+                this, &KTreeViewSearchLine::treeViewDeleted );
 
-    disconnect( treeView->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                this, SLOT(rowsInserted(QModelIndex,int,int)) );
+    disconnect( treeView->model(), &QAbstractItemModel::rowsInserted,
+                this, &KTreeViewSearchLine::rowsInserted );
   }
 }
 
@@ -336,6 +338,20 @@ void KTreeViewSearchLine::activateSearch()
     updateSearch( d->search );
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// private functions
+////////////////////////////////////////////////////////////////////////////////
+
+void KTreeViewSearchLine::rowsInserted(const QModelIndex & parent, int start, int end) const
+{
+    d->rowsInserted(parent, start, end);
+}
+
+void KTreeViewSearchLine::treeViewDeleted( QObject *treeView )
+{
+    d->treeViewDeleted( treeView );
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // KTreeViewSearchLineWidget
 ////////////////////////////////////////////////////////////////////////////////
