@@ -52,7 +52,7 @@ class PageViewAnnotator : public QObject
     Q_OBJECT
     public:
         PageViewAnnotator( PageView * parent, Okular::Document * storage );
-        ~PageViewAnnotator();
+        ~PageViewAnnotator() override;
 
         // called to show/hide the editing toolbar
         void setEnabled( bool enabled );
@@ -76,19 +76,19 @@ class PageViewAnnotator : public QObject
         QCursor cursor() const;
 
         QRect routeMouseEvent( QMouseEvent * event, PageViewItem * item );
-        QRect routeTabletEvent( QTabletEvent * event, PageViewItem * item, const QPoint & localOriginInGlobal );
-        QRect performRouteMouseOrTabletEvent( const AnnotatorEngine::EventType & eventType, const AnnotatorEngine::Button & button,
-                                              const QPointF & pos, PageViewItem * item );
+        QRect routeTabletEvent( QTabletEvent * event, PageViewItem * item, const QPoint localOriginInGlobal );
+        QRect performRouteMouseOrTabletEvent( const AnnotatorEngine::EventType eventType, const AnnotatorEngine::Button button,
+                                              const QPointF pos, PageViewItem * item );
         bool routeKeyEvent( QKeyEvent * event );
-        bool routePaints( const QRect & wantedRect ) const;
-        void routePaint( QPainter * painter, const QRect & paintRect );
+        bool routePaints( const QRect wantedRect ) const;
+        void routePaint( QPainter * painter, const QRect paintRect );
 
         void reparseConfig();
 
         static QString defaultToolName( const QDomElement &toolElement );
         static QPixmap makeToolPixmap( const QDomElement &toolElement );
 
-    private slots:
+    private Q_SLOTS:
         void slotToolSelected( int toolID );
         void slotSaveToolbarOrientation( int side );
         void slotToolDoubleClicked( int toolID );
