@@ -37,7 +37,6 @@
 #include <kactioncollection.h>
 #include <klineedit.h>
 #include <KLocalizedString>
-#include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kselectaction.h>
 #include <QDialog>
@@ -102,7 +101,8 @@ struct PresentationFrame
                           ( height - pageHeight ) / 2,
                           pageWidth, pageHeight );
 
-        Q_FOREACH ( VideoWidget *vw, videoWidgets )
+
+        for ( VideoWidget *vw : qAsConst(videoWidgets) )
         {
             const Okular::NormalizedRect r = vw->normGeometry();
             QRect vwgeom = r.geometry( geometry.width(), geometry.height() );
@@ -200,7 +200,8 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     addAction( playPauseAct );
     m_topBar->addSeparator();
 
-    foreach(QAction *action, drawingToolActions->actions())
+    const QList<QAction *> actionsList = drawingToolActions->actions();
+    for (QAction *action : actionsList)
     {
         action->setEnabled( true );
         m_topBar->addAction( action );
@@ -305,7 +306,8 @@ PresentationWidget::~PresentationWidget()
     // remove this widget from document observer
     m_document->removeObserver( this );
 
-    foreach( QAction *action, m_topBar->actions() )
+    const QList<QAction *> actionsList = actions();
+    for ( QAction *action : actionsList )
     {
         action->setChecked( false );
         action->setEnabled( false );
@@ -413,7 +415,7 @@ void PresentationWidget::notifyCurrentPageChanged( int previousPage, int current
     if ( previousPage != -1 )
     {
         // stop video playback
-        Q_FOREACH ( VideoWidget *vw, m_frames[ previousPage ]->videoWidgets )
+        for ( VideoWidget *vw : qAsConst(m_frames[ previousPage ]->videoWidgets) )
         {
             vw->stop();
             vw->pageLeft();
@@ -427,7 +429,8 @@ void PresentationWidget::notifyCurrentPageChanged( int previousPage, int current
             m_document->processAction( m_document->page( previousPage )->pageAction( Okular::Page::Closing ) );
 
         // perform the additional actions of the page's annotations, if any
-        Q_FOREACH ( const Okular::Annotation *annotation, m_document->page( previousPage )->annotations() )
+        const QLinkedList< Okular::Annotation* > annotationsList = m_document->page( previousPage )->annotations();
+        for ( const Okular::Annotation *annotation : annotationsList )
         {
             Okular::Action *action = nullptr;
 
@@ -472,7 +475,8 @@ void PresentationWidget::notifyCurrentPageChanged( int previousPage, int current
             m_document->processAction( m_document->page( m_frameIndex )->pageAction( Okular::Page::Opening ) );
 
         // perform the additional actions of the page's annotations, if any
-        Q_FOREACH ( const Okular::Annotation *annotation, m_document->page( m_frameIndex )->annotations() )
+        const QLinkedList< Okular::Annotation* > annotationsList = m_document->page( m_frameIndex )->annotations();
+        for ( const Okular::Annotation *annotation : annotationsList )
         {
             Okular::Action *action = nullptr;
 
@@ -486,8 +490,9 @@ void PresentationWidget::notifyCurrentPageChanged( int previousPage, int current
         }
 
         // start autoplay video playback
-        Q_FOREACH ( VideoWidget *vw, m_frames[ m_frameIndex ]->videoWidgets )
+        for ( VideoWidget *vw : qAsConst(m_frames[ m_frameIndex ]->videoWidgets) ) {
             vw->pageEntered();
+        }
     }
 }
 
@@ -932,8 +937,9 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
         pmPainter.setRenderHints( QPainter::Antialiasing );
 
         // Paint old paths
-        foreach ( const SmoothPath &drawing, m_frames[ m_frameIndex ]->drawings )
+        for ( const SmoothPath &drawing : qAsConst(m_frames[ m_frameIndex ]->drawings) ) {
             drawing.paint( &pmPainter, pmSize.width(), pmSize.height() );
+        }
 
         // Paint the path that is currently being drawn by the user
         if ( m_drawingEngine && m_drawingRect.intersects( pe->rect() ) )
@@ -1036,7 +1042,7 @@ void PresentationWidget::testCursorOnLink( int x, int y )
     }
 }
 
-void PresentationWidget::overlayClick( const QPoint & position )
+void PresentationWidget::overlayClick( const QPoint position )
 {
     // clicking the progress indicator
     int xPos = position.x() - m_overlayGeometry.x() - m_overlayGeometry.width() / 2,
@@ -1147,7 +1153,7 @@ void PresentationWidget::generateIntroPage( QPainter & p )
     }
 
     // draw okular logo in the four corners
-    QPixmap logo = DesktopIcon( QStringLiteral("okular"), 64 * dpr );
+    QPixmap logo = QIcon::fromTheme( QStringLiteral("okular") ).pixmap( 64 * dpr );
     logo.setDevicePixelRatio( dpr );
     if ( !logo.isNull() )
     {
@@ -1219,7 +1225,7 @@ void PresentationWidget::generateOverlay()
     qreal dpr = qApp->devicePixelRatio();
 
     // calculate overlay geometry and resize pixmap if needed
-    int side = m_width / 16;
+    double side = m_width / 16.0;
     m_overlayGeometry.setRect( m_width - side - 4, 4, side, side );
 
     // note: to get a sort of antialiasing, we render the pixmap double sized
@@ -1296,8 +1302,8 @@ void PresentationWidget::generateOverlay()
     color = pal.color( QPalette::Active, QPalette::Highlight );
     int sRed = color.red(), sGreen = color.green(), sBlue = color.blue();
     // pointers
-    unsigned int * data = (unsigned int *)image.bits(),
-                 * shadowData = (unsigned int *)shadow.bits(),
+    unsigned int * data = reinterpret_cast<unsigned int *>(image.bits()),
+                 * shadowData = reinterpret_cast<unsigned int *>(shadow.bits()),
                  pixels = image.width() * image.height();
     // cache data (reduce computation time to 26%!)
     int c1 = -1, c2 = -1, cR = 0, cG = 0, cB = 0, cA = 0;
@@ -1691,7 +1697,9 @@ void PresentationWidget::slotChangeDrawingToolEngine( const QDomElement &element
 void PresentationWidget::slotAddDrawingToolActions()
 {
     DrawingToolActions *drawingToolActions = qobject_cast<DrawingToolActions*>(sender());
-    foreach(QAction *action, drawingToolActions->actions()) {
+
+    const QList<QAction *> actionsList = drawingToolActions->actions();
+    for (QAction *action : actionsList) {
         action->setEnabled( true );
         m_topBar->addAction( action );
         addAction( action );
@@ -1743,7 +1751,7 @@ void PresentationWidget::setScreen( int newScreen )
     applyNewScreenSize( oldSize );
 }
 
-void PresentationWidget::applyNewScreenSize( const QSize & oldSize )
+void PresentationWidget::applyNewScreenSize( const QSize oldSize )
 {
     repositionContent();
 
