@@ -32,7 +32,7 @@ class ThumbnailList : public QScrollArea, public Okular::DocumentObserver
 Q_OBJECT
     public:
         ThumbnailList(QWidget *parent, Okular::Document *document);
-        ~ThumbnailList();
+        ~ThumbnailList() override;
 
         // inherited: create thumbnails ( inherited as a DocumentObserver )
         void notifySetup( const QVector< Okular::Page * > & pages, int setupFlags ) override;
@@ -56,20 +56,17 @@ Q_OBJECT
 
     protected:
         // scroll up/down the view
-        void keyPressEvent( QKeyEvent * e ) override;
+        void keyPressEvent( QKeyEvent * keyEvent ) override;
 
         // catch the viewport event and filter them if necessary
         bool viewportEvent( QEvent * ) override;
 
     Q_SIGNALS:
-        void rightClick( const Okular::Page *, const QPoint & );
+        void rightClick( const Okular::Page *, const QPoint );
 
     private:
         friend class ThumbnailListPrivate;
         ThumbnailListPrivate *d;
-
-        Q_PRIVATE_SLOT( d, void slotRequestVisiblePixmaps( int newContentsY = -1 ) )
-        Q_PRIVATE_SLOT( d, void slotDelayTimeout() )
 };
 
 /**
