@@ -24,7 +24,7 @@ class VideoWidget : public QWidget
     Q_OBJECT
     public:
         VideoWidget( const Okular::Annotation *annot, Okular::Movie *movie, Okular::Document *document, QWidget *parent = nullptr );
-        ~VideoWidget();
+        ~VideoWidget() override;
 
         void setNormGeometry( const Okular::NormalizedRect &rect );
         Okular::NormalizedRect normGeometry() const;
@@ -57,11 +57,6 @@ class VideoWidget : public QWidget
         void resizeEvent( QResizeEvent * event ) override;
 
     private:
-        Q_PRIVATE_SLOT( d, void finished() )
-        Q_PRIVATE_SLOT( d, void playOrPause() )
-        Q_PRIVATE_SLOT( d, void setPosterImage( const QImage& ) )
-        Q_PRIVATE_SLOT( d, void stateChanged( Phonon::State, Phonon::State ) )
-
         // private storage
         class Private;
         Private *d;
